==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/pt_PT.php <==
<?php
$lang['friendlyname'] = 'Gestor de Arquivos';
$lang['permission'] = 'Utiliza&ccedil;&atilde;o do Gerenciador de Arquivos';
$lang['permissionadvanced'] = 'Uso avan&ccedil;ado do Gestor de Arquivos';
$lang['moddescription'] = 'Manipula&ccedil;&atilde;o de arquivos e diret&oacute;rios';
$lang['installed'] = 'Gestor de Arquivos vers&atilde;o %s instalado';
$lang['postinstall'] = 'Gestor de Arquivos instalado';
$lang['uninstalled'] = 'Gestor de Arquivos desinstalado';
$lang['really_uninstall'] = 'Tem a certeza que pretende desinstalar o Gestor de Arquivos?';
$lang['upgraded'] = 'Gestor de Arquivos foi actualizado para a vers&atilde;o %s';
$lang['fileview'] = 'Ver Arquivo';
$lang['switchtofileview'] = 'Mudar para a visualiza&ccedil;&atilde;o de arquivos';
$lang['settings'] = 'Configura&ccedil;&otilde;es';
$lang['savesettings'] = 'Guardar configura&ccedil;&otilde;es';
$lang['filename'] = 'Arquivo nome';
$lang['fileinfo'] = 'Info';
$lang['fileowner'] = 'Arquivo Permiss&atilde;o';
$lang['fileperms'] = 'Permiss&otilde;es';
$lang['filesize'] = 'Tamanho';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Ac&ccedil;&otilde;es';
$lang['delete'] = 'Eliminar';
$lang['notwritable'] = 'Sem permiss&otilde;es de escrita ';
$lang['filetoobig'] = '&eacute; demasiado pesado. Tranfer&ecirc;ncia cancelada.';
$lang['unknown'] = 'Desconhecido';
$lang['fileoutsideuploads'] = 'N&atilde;o est&aacute; autorizado a modificar arquivos fora das Imagens-dir! (Isso exige a permiss&atilde;o de Gest&atilde;o Avan&ccedil;ada)';
$lang['writable'] = 'Grav&aacute;vel';
$lang['writeprotected'] = 'Escrita protegida';
$lang['bytes'] = 'Bytes';
$lang['kb'] = 'Kb';
$lang['mb'] = 'Mb';
$lang['files'] = 'arquivos';
$lang['bytesin'] = 'bytes em';
$lang['in'] = 'em';
$lang['file'] = 'arquivo';
$lang['fileno'] = 'Arquivo n&ordm;';
$lang['subdirs'] = 'subpastas';
$lang['subdir'] = 'subpasta';
$lang['and'] = 'e';
$lang['confirmsingledelete'] = 'Tem a certeza?';
$lang['confirmsingledirdelete'] = 'Tem a certeza que pertende eliminar esta pasta?';
$lang['dirtreedeletesuccess'] = 'A pasta incluindo o seu conte&uacute;do foi eliminada.';
$lang['dirtreedeletefail'] = 'Ocorreu um erro ao excluir esta pasta. Alguns dos conte&uacute;dos podem ter sido exclu&iacute;dos entretanto.';
$lang['singlefiledeletesuccess'] = 'O arquivo foi eliminado com sucesso.';
$lang['filedeletesuccess'] = 'foi exclu&iacute;do com &ecirc;xito';
$lang['singlefiledeletefail'] = 'Ocorreu um erro ao tentar apagar o arquivo';
$lang['filedeletefail'] = 'n&atilde;o foi exclu&iacute;do devido a um erro';
$lang['singledirdeletesuccess'] = 'A pasta foi exclu&iacute;da com &ecirc;xito';
$lang['singledirdeletefail'] = 'Ocorreu um erro ao tentar apagar a pasta (a mesma encontra-se est&aacute; vazia!)';
$lang['deleteselected'] = 'Eliminar os arquivos selecionados';
$lang['confirmselected'] = 'Tem a Certeza?';
$lang['confirmdeleteselected'] = 'Tem a certeza que os arquivos selecionados devem ser eliminados?';
$lang['deleteselectedcancelled'] = 'A Elimina&ccedil;&atilde;o dos arquivos selecionados cancelada';
$lang['recursetext'] = 'Recurso em subpastas (ainda n&atilde;o implementado)';
$lang['nofilesselected'] = 'N&atilde;o foi selecionado nenhum arquivo';
$lang['moveselected'] = 'Mover os arquivos selecionados';
$lang['copyselected'] = 'Copiar os arquivos selecionados';
$lang['selecttargetdir'] = 'Selecione o destino para mover/copiar';
$lang['movedto'] = 'movido para';
$lang['copiedto'] = 'copiado para';
$lang['couldnotmove'] = 'n&atilde;o pode ser movido';
$lang['couldnotcopy'] = 'n&atilde;o pode ser copiado';
$lang['rename'] = 'Modificar';
$lang['newname'] = 'Novo nome:';
$lang['renamesuccess'] = 'Arquivo modificado com sucesso';
$lang['renamefailure'] = 'Falha ao modificar o arquivo';
$lang['renamecancelled'] = 'Modifica&ccedil;&atilde;o cancelada';
$lang['owner'] = 'Permiss&otilde;es';
$lang['group'] = 'Groupo';
$lang['others'] = 'Outros';
$lang['newpermissions'] = 'Novas permiss&otilde;es:';
$lang['setpermissions'] = 'Definir permiss&otilde;es';
$lang['permissionstyle'] = 'Estilo das permiss&otilde;es';
$lang['rwxstyle'] = 'rwx estilo';
$lang['755style'] = '755 estilo';
$lang['quickmode'] = 'R&aacute;pido chmod (ex. 777)';
$lang['chmod'] = 'Mofificar permiss&otilde;es';
$lang['chmodselected'] = 'Modificar permiss&otilde;es nos arquivos seleccionados';
$lang['chmodsuccess'] = 'Arquivo obteve &ecirc;xito nas novas permiss&otilde;es';
$lang['chmodfailure'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es do arquivo falhado';
$lang['chmodcancelled'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es cancelada';
$lang['dirchmodfailmulti'] = 'Mudar permiss&otilde;es no direct&oacute;rio falhado, alguns dos conte&uacute;dos podem ter adquirido novas permiss&otilde;es, no entretanto.';
$lang['dirchmodsuccessmulti'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es sobre o conte&uacute;do do diret&oacute;rio foi bem-sucedida';
$lang['dirchmodsuccess'] = 'As novas permiss&otilde;es foram atribu&iacute;das com &ecirc;xito';
$lang['dirchmodfailure'] = 'A modifica&ccedil;&atilde;o das permiss&otilde;es falharam';
$lang['dirnotemptyconfirm'] = 'Esta pasta n&atilde;o est&aacute; vazia. Deseja realmente apag&aacute;-la e todo o seu conte&uacute;do, incluindo sub-pastas?<br/><br/>';
$lang['dirtreedeletecancelled'] = 'Elimina&ccedil;&atilde;o da pasta cancelada';
$lang['imsure'] = 'Tenho a Certeza';
$lang['cancel'] = 'Cancelar';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Carregar novo(s) arquivo(s):';
$lang['unpackafterupload'] = 'Tentar descompactar (apenas tgz e zip)';
$lang['uploadsuccess'] = 'foi carregado com sucesso';
$lang['uploadfail'] = 'falha no carregamento';
$lang['unpacksuccess'] = 'foi descompactado com sucesso';
$lang['unpackfail'] = 'falha com este erro:';
$lang['packfileopenfail'] = 'N&atilde;o foi poss&iacute;vel abrir o arquivo compactado, para descompactar (formato n&atilde;o suportado!)';
$lang['packfilewritefail'] = 'N&atilde;o foi poss&iacute;vel abrir o arquivo &amp;s para escrita';
$lang['currentpath'] = 'Situado em:';
$lang['newdirname'] = 'Criar nova pasta:';
$lang['newdirsuccess'] = 'Pasta criada com sucesso';
$lang['newdirfail'] = 'Ocorreu um erro ao tentar criar a pasta';
$lang['invalidnewdir'] = 'O Nome do novo diret&oacute;rio n&atilde;o pode conter caracteres como /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Tamanho do Icon';
$lang['smallicons'] = 'Icons pequenos';
$lang['largeicons'] = 'Icons grandes';
$lang['thousanddelimiter'] = 'Delimitador';
$lang['none'] = 'Nenhum';
$lang['space'] = 'espa&ccedil;o';
$lang['showthumbnails'] = 'Mostrar miniaturas';
$lang['showthumbnailshelp'] = 'A activa&ccedil;&atilde;o das miniaturas iram mostrar arquivos de imagem-se que existam, <br/>e vai esconder as reais miniatura-arquivo. <br/> A desactiva&ccedil;&atilde;o simplesmente ir&aacute; mostrar todos os arquivos.';
$lang['uploadfilesto'] = 'Carregar arquivos para:';
$lang['uploadview'] = 'Carregar arquivos';
$lang['uploadboxes'] = 'N&uacute;mero de caixas de carregamento';
$lang['nothinguploaded'] = 'Nada foi carregado';
$lang['unsupportedarchive'] = 'Formato do arquivo n&atilde;o suportado';
$lang['uploadmethod'] = 'M&eacute;todo de carregamento';
$lang['uploaderstandard'] = 'Pad&atilde;o html input-method (permite descompactar)';
$lang['enableadvanced'] = 'Activar o modo avan&ccedil;ado?';
$lang['advancedhelp'] = 'Permite-lhe aceder a todos os arquivos, e n&atilde;o apenas a:  /uploads/';
$lang['showhiddenfileshelp'] = 'S&oacute; &eacute; eficaz com o modo avan&ccedil;ado ON';
$lang['showhiddenfiles'] = 'Mostrar arquivos ocultos';
$lang['settingsconfirmsingledelete'] = 'Confirma a elimina&ccedil;&atilde;o de um &uacute;nico arquivo?';
$lang['settingssaved'] = 'Configura&ccedil;&otilde;es salvas';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. </p>
<h3>Tradu&ccedil;&atilde;o Portuguesa</h3>
		<p>Nuno costa <nuno.mfcosta@sapo.pt></p>';
$lang['utma'] = '156861353.3089450601847726600.1241711306.1242169415.1242211460.31';
$lang['utmz'] = '156861353.1242165449.29.8.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p1.tgz: cms/modules/FileManager/lang/ext/pt_PT.php <==
<?php
$lang['friendlyname'] = 'Gestor de Arquivos';
$lang['permission'] = 'Utiliza&ccedil;&atilde;o do Gerenciador de Arquivos';
$lang['permissionadvanced'] = 'Uso avan&ccedil;ado do Gestor de Arquivos';
$lang['moddescription'] = 'Manipula&ccedil;&atilde;o de arquivos e diret&oacute;rios';
$lang['installed'] = 'Gestor de Arquivos vers&atilde;o %s instalado';
$lang['postinstall'] = 'Gestor de Arquivos instalado';
$lang['uninstalled'] = 'Gestor de Arquivos desinstalado';
$lang['really_uninstall'] = 'Tem a certeza que pretende desinstalar o Gestor de Arquivos?';
$lang['upgraded'] = 'Gestor de Arquivos foi actualizado para a vers&atilde;o %s';
$lang['fileview'] = 'Ver Arquivo';
$lang['switchtofileview'] = 'Mudar para a visualiza&ccedil;&atilde;o de arquivos';
$lang['settings'] = 'Configura&ccedil;&otilde;es';
$lang['savesettings'] = 'Guardar configura&ccedil;&otilde;es';
$lang['filename'] = 'Arquivo nome';
$lang['fileinfo'] = 'Info';
$lang['fileowner'] = 'Arquivo Permiss&atilde;o';
$lang['fileperms'] = 'Permiss&otilde;es';
$lang['filesize'] = 'Tamanho';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Ac&ccedil;&otilde;es';
$lang['delete'] = 'Eliminar';
$lang['notwritable'] = 'Sem permiss&otilde;es de escrita ';
$lang['filetoobig'] = '&eacute; demasiado pesado. Tranfer&ecirc;ncia cancelada.';
$lang['unknown'] = 'Desconhecido';
$lang['fileoutsideuploads'] = 'N&atilde;o est&aacute; autorizado a modificar arquivos fora das Imagens-dir! (Isso exige a permiss&atilde;o de Gest&atilde;o Avan&ccedil;ada)';
$lang['writable'] = 'Grav&aacute;vel';
$lang['writeprotected'] = 'Escrita protegida';
$lang['bytes'] = 'Bytes';
$lang['kb'] = 'Kb';
$lang['mb'] = 'Mb';
$lang['files'] = 'arquivos';
$lang['bytesin'] = 'bytes em';
$lang['in'] = 'em';
$lang['file'] = 'arquivo';
$lang['fileno'] = 'Arquivo n&ordm;';
$lang['subdirs'] = 'subpastas';
$lang['subdir'] = 'subpasta';
$lang['and'] = 'e';
$lang['confirmsingledelete'] = 'Tem a certeza?';
$lang['confirmsingledirdelete'] = 'Tem a certeza que pertende eliminar esta pasta?';
$lang['dirtreedeletesuccess'] = 'A pasta incluindo o seu conte&uacute;do foi eliminada.';
$lang['dirtreedeletefail'] = 'Ocorreu um erro ao excluir esta pasta. Alguns dos conte&uacute;dos podem ter sido exclu&iacute;dos entretanto.';
$lang['singlefiledeletesuccess'] = 'O arquivo foi eliminado com sucesso.';
$lang['filedeletesuccess'] = 'foi exclu&iacute;do com &ecirc;xito';
$lang['singlefiledeletefail'] = 'Ocorreu um erro ao tentar apagar o arquivo';
$lang['filedeletefail'] = 'n&atilde;o foi exclu&iacute;do devido a um erro';
$lang['singledirdeletesuccess'] = 'A pasta foi exclu&iacute;da com &ecirc;xito';
$lang['singledirdeletefail'] = 'Ocorreu um erro ao tentar apagar a pasta (a mesma encontra-se est&aacute; vazia!)';
$lang['deleteselected'] = 'Eliminar os arquivos selecionados';
$lang['confirmselected'] = 'Tem a Certeza?';
$lang['confirmdeleteselected'] = 'Tem a certeza que os arquivos selecionados devem ser eliminados?';
$lang['deleteselectedcancelled'] = 'A Elimina&ccedil;&atilde;o dos arquivos selecionados cancelada';
$lang['recursetext'] = 'Recurso em subpastas (ainda n&atilde;o implementado)';
$lang['nofilesselected'] = 'N&atilde;o foi selecionado nenhum arquivo';
$lang['moveselected'] = 'Mover os arquivos selecionados';
$lang['copyselected'] = 'Copiar os arquivos selecionados';
$lang['selecttargetdir'] = 'Selecione o destino para mover/copiar';
$lang['movedto'] = 'movido para';
$lang['copiedto'] = 'copiado para';
$lang['couldnotmove'] = 'n&atilde;o pode ser movido';
$lang['couldnotcopy'] = 'n&atilde;o pode ser copiado';
$lang['rename'] = 'Modificar';
$lang['newname'] = 'Novo nome:';
$lang['renamesuccess'] = 'Arquivo modificado com sucesso';
$lang['renamefailure'] = 'Falha ao modificar o arquivo';
$lang['renamecancelled'] = 'Modifica&ccedil;&atilde;o cancelada';
$lang['owner'] = 'Permiss&otilde;es';
$lang['group'] = 'Groupo';
$lang['others'] = 'Outros';
$lang['newpermissions'] = 'Novas permiss&otilde;es:';
$lang['setpermissions'] = 'Definir permiss&otilde;es';
$lang['permissionstyle'] = 'Estilo das permiss&otilde;es';
$lang['rwxstyle'] = 'rwx estilo';
$lang['755style'] = '755 estilo';
$lang['quickmode'] = 'R&aacute;pido chmod (ex. 777)';
$lang['chmod'] = 'Mofificar permiss&otilde;es';
$lang['chmodselected'] = 'Modificar permiss&otilde;es nos arquivos seleccionados';
$lang['chmodsuccess'] = 'Arquivo obteve &ecirc;xito nas novas permiss&otilde;es';
$lang['chmodfailure'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es do arquivo falhado';
$lang['chmodcancelled'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es cancelada';
$lang['dirchmodfailmulti'] = 'Mudar permiss&otilde;es no direct&oacute;rio falhado, alguns dos conte&uacute;dos podem ter adquirido novas permiss&otilde;es, no entretanto.';
$lang['dirchmodsuccessmulti'] = 'Altera&ccedil;&atilde;o das permiss&otilde;es sobre o conte&uacute;do do diret&oacute;rio foi bem-sucedida';
$lang['dirchmodsuccess'] = 'As novas permiss&otilde;es foram atribu&iacute;das com &ecirc;xito';
$lang['dirchmodfailure'] = 'A modifica&ccedil;&atilde;o das permiss&otilde;es falharam';
$lang['dirnotemptyconfirm'] = 'Esta pasta n&atilde;o est&aacute; vazia. Deseja realmente apag&aacute;-la e todo o seu conte&uacute;do, incluindo sub-pastas?<br/><br/>';
$lang['dirtreedeletecancelled'] = 'Elimina&ccedil;&atilde;o da pasta cancelada';
$lang['imsure'] = 'Tenho a Certeza';
$lang['cancel'] = 'Cancelar';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Carregar novo(s) arquivo(s):';
$lang['unpackafterupload'] = 'Tentar descompactar (apenas tgz e zip)';
$lang['uploadsuccess'] = 'foi carregado com sucesso';
$lang['uploadfail'] = 'falha no carregamento';
$lang['unpacksuccess'] = 'foi descompactado com sucesso';
$lang['unpackfail'] = 'falha com este erro:';
$lang['packfileopenfail'] = 'N&atilde;o foi poss&iacute;vel abrir o arquivo compactado, para descompactar (formato n&atilde;o suportado!)';
$lang['packfilewritefail'] = 'N&atilde;o foi poss&iacute;vel abrir o arquivo &amp;s para escrita';
$lang['containsillegalchars'] = 'O nome do ficheito contem um ou mais caracteres especiais (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Situado em:';
$lang['newdirname'] = 'Criar nova pasta:';
$lang['newdirsuccess'] = 'Pasta criada com sucesso';
$lang['newdirfail'] = 'Ocorreu um erro ao tentar criar a pasta';
$lang['invalidnewdir'] = 'O Nome do novo diret&oacute;rio n&atilde;o pode conter caracteres como /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Tamanho do Icon';
$lang['smallicons'] = 'Icons pequenos';
$lang['largeicons'] = 'Icons grandes';
$lang['thousanddelimiter'] = 'Delimitador';
$lang['none'] = 'Nenhum';
$lang['space'] = 'espa&ccedil;o';
$lang['showthumbnails'] = 'Mostrar miniaturas';
$lang['showthumbnailshelp'] = 'A activa&ccedil;&atilde;o das miniaturas iram mostrar arquivos de imagem-se que existam, <br/>e vai esconder as reais miniatura-arquivo. <br/> A desactiva&ccedil;&atilde;o simplesmente ir&aacute; mostrar todos os arquivos.';
$lang['uploadfilesto'] = 'Carregar arquivos para:';
$lang['uploadview'] = 'Carregar arquivos';
$lang['uploadboxes'] = 'N&uacute;mero de caixas de carregamento';
$lang['nothinguploaded'] = 'Nada foi carregado';
$lang['unsupportedarchive'] = 'Formato do arquivo n&atilde;o suportado';
$lang['uploadmethod'] = 'M&eacute;todo de carregamento';
$lang['uploaderstandard'] = 'Pad&atilde;o html input-method (permite descompactar)';
$lang['enableadvanced'] = 'Activar o modo avan&ccedil;ado?';
$lang['advancedhelp'] = 'Permite-lhe aceder a todos os arquivos, e n&atilde;o apenas a:  /uploads/';
$lang['showhiddenfileshelp'] = 'S&oacute; &eacute; eficaz com o modo avan&ccedil;ado ON';
$lang['showhiddenfiles'] = 'Mostrar arquivos ocultos';
$lang['settingsconfirmsingledelete'] = 'Confirma a elimina&ccedil;&atilde;o de um &uacute;nico arquivo?';
$lang['settingssaved'] = 'Configura&ccedil;&otilde;es salvas';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. </p>
<h3>Tradu&ccedil;&atilde;o Portuguesa</h3>
		<p>Nuno costa <nuno.mfcosta@sapo.pt></p>';
$lang['utma'] = '156861353.1237943808.1260371543.1269303018.1269308063.80';
$lang['utmz'] = '156861353.1269224531.76.37.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['qca'] = 'P0-938093432-1260371543221';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
